class HttpReponseInitialAuth():
    def __init__(self, json_response):
        self.email: str = None
        self.num_of_projects: int = None
        
        self._parser(json_response)
    
    
    def _parser(self, json_response):
        self.email = json_response['email'] \
            if 'email' in json_response else None
        
        self.num_of_projects = json_response['num_of_projects'] \
            if 'num_of_projects' in json_response else None


from geox.factory.project_factory import ProjectFactory
from geox.project import Project


class HttpReponseProject():
    def __init__(self, json_response):
        self.project: Project = None
        
        self._factory = ProjectFactory()
        self._parser(json_response)
    
    
    def _parser(self, json_response):
        self.project = self._factory.create(json_response)



from time import sleep
from geox.exceptions import APIKeyException, ParameterException, ServerErrorException
from http import HTTPStatus
from requests import request, Response
from requests.exceptions import ConnectionError


def check_status_code(response: Response) -> None:
    '''checking all available status code from GeoX API'''
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        raise APIKeyException(f'Unauthorized. {response.json()["detail"]}.')
    
    elif response.status_code == HTTPStatus.BAD_REQUEST:
        raise ParameterException(f'Some of the parameter in request is invalid. {response.text}.')
    
    elif response.status_code == HTTPStatus.NOT_FOUND:
        raise ServerErrorException('404. Not Found response, server error.')

def connect_to_endpoint(url: str, method: str, headers: dict={}, params:dict ={}) -> dict:
    '''Connect to endpoint'''
    try:
        response = request(
            method=method, 
            url=url, 
            headers = headers, 
            params = params,
            verify=False,
            )
        
        # checking status code
        check_status_code(response)

        return response.json()
    
    except ParameterException as e:
        print(e)
        # sys.exit()
        return {}
    
    except ConnectionError as e:
        print('Connection Error. Retrying in 5 seconds')
        sleep(5)
        return connect_to_endpoint(url, method, headers, params)


from geox.version import VERSION
from setuptools import setup
import pathlib


BASE_DIR = pathlib.Path(__file__).parent
README = (BASE_DIR / "README.md").read_text()

setup(
    name="geox",
    version=VERSION,
    author="GeoX",
    author_email="geoxdat@gmail.com",
    url='https://github.com/geoxdat/geox',
    description="GeoX, Geostatic Dataset Integration Tool",
    long_description=README,
    long_description_content_type="text/markdown",
    license='MIT',
    packages=[
        'geox', 
        'geox/api_caller',
        'geox/entity',
        'geox/factory',
        'geox/http_response',
        ],
    include_package_data=True,
    install_requires=[
        'numpy',
        'pandas',
        'pytest',
        'pytz',
        'requests',
        'tqdm',
        ],
    keywords=['geox', 'geostatistic', 'mining', 'dataset'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



class DatasetType:
    """All type of dataset
    """
    COLLAR = 'collar'
    SURVEY = 'survey'
    ALTERATION = 'alteration'
    ASSAY = 'assay'
    LITHO = 'litho'
    MINERALISATION = 'mineralisation'